
/*
Function for Accelerometer processing. Input an array of accelereation values. Output paced RR
The RR will be paced only if a significant acceleration is found.

The code is based on the decision tree model of K. Ohkawara et al 2011
The decision tree estimate the metabolism MET,
The HR estimation (given the metabolism) is based on the works "A Mathematical Model of the Cardiac Chronotropic Response to Exercise"


*/
 


double accelerometer_processing(int *chandata_x , int *chandata_y , int *chandata_z)
{
	int chandata_filtered_x[lines];
	int chandata_filtered_y[lines];
	int chandata_filtered_z[lines];
	int chandata_MOD[lines];
	int chandata_filtered_MOD[lines];
	int i;
	double RR , HR;
	int ACC_fil_digital;
	int ACC_unfil_digital;
	double ACC_fil;
	double ACC_unfil;
	double temp;
	double MET;
	static double HR_rest=60.0/REST_RR;


	filtering_acc_singal(chandata_x, chandata_filtered_x);		/* filtering the background out */
	filtering_acc_singal(chandata_y, chandata_filtered_y);		/* filtering the background out */
	filtering_acc_singal(chandata_z, chandata_filtered_z);		/* filtering the background out */

	for(i=0;i<lines;i++)
	{	
		chandata_MOD[i]=(abs(chandata_x[i])+abs(chandata_y[i])+abs(chandata_z[i]));				/* computing abs ( it should be norm2 if 3-axial accelerometers) */
		chandata_filtered_MOD[i]=(abs(chandata_filtered_x[i])+abs(chandata_filtered_y[i])+abs(chandata_filtered_z[i]));  /* JUST A POOR APPROXIMATION!!!*/
	}
	
	ACC_unfil_digital=mean_computation(chandata_MOD, lines);
	ACC_fil_digital=mean_computation(chandata_filtered_MOD, lines);


	ACC_unfil=DAC_converter(ACC_unfil_digital,BIT_PRECISION);
	ACC_fil=DAC_converter(ACC_fil_digital,BIT_PRECISION);

	if(ACC_fil<=ACTIVITY_THERESHOLD)			/* if no activity has been found, return Rest RR*/
	{
		RR=REST_RR;			
	}
	else
	{
		/*printf("Deciding: %lf \n", ACC_unfil/ACC_fil); */
		if(ACC_unfil>=SCALE_FACTOR*ACC_fil)		/* case 1: light activity */
		{
			MET=ACC0+(ACC1*ACC_fil);
			/*printf("Light activity, MET= %.3lf \n" , MET); */
		}
		else					/*case 2: locomotive activity  */
		{
			MET=ACC2+(ACC3*ACC_fil);
			/*printf("Locomotive activity, MET= %.3lf \n" , MET); */
		}
	
		/*temp=DELTA*(temp); */
		/*printf("temp: %f   ", temp); */
	    HR=((220.0-AGE-HR_rest)*(MET-1.0)/(MET_max-1.0))+HR_rest;
		RR=60.0/HR;
			

	}
	return(RR);
}

