	
	ecg=load(ECG_txt_file);
	ecg=ecg(:,1);

	%%Adding necessary paths, and loading default model parameters
	ECG_detect_path='ECG_detect/';
	default_model_param=[ECG_detect_path,'workspace_unstruct.mat'];
	addpath(ECG_detect_path);
	load(default_model_param);

	%keeping just a minute of ecg record
	ecg_sig = ecg(1:fs*60); 

	tLimit_sim = min(length(ecg_sig)/fs,120);
	
	%extracting observable parameters
    
    
	[ParECG,filteredECG] = genECGParam(ecg_sig,fs,60,debug,0.1);
    ParECG=clean_outliers(ParECG);


	bestSynthECGs = [];

	

	%%Running SUMO optimization
	surrogateModels = go('config/personalized_heart.xml');
    
    clc;
    
	model=surrogateModels{1}{1};
	[lbs,ubs] = model.getBounds;
	paramNames = model.getInputNames;
	samples = [model.getSamples, model.getValues];
	%figure



	SIZE_OF_GRID=100;
	Bx=[lbs(1),ubs(1)];   
	By=[lbs(2),ubs(2)];   
	X=linspace( Bx(1), Bx(2) , SIZE_OF_GRID );
	Y=linspace( By(1), By(2) , SIZE_OF_GRID );
	meanVal=zeros(SIZE_OF_GRID,SIZE_OF_GRID);
	varianceVal=zeros(SIZE_OF_GRID,SIZE_OF_GRID);
	for ii=1:length(X)
	  for jj=1:length(Y)
	       %evaluating variance of kriging model  at point x(ii)  y(jj) which correspond to z(jj,ii) for surf plot
	       [meanVal(jj,ii),varianceVal(jj,ii)]=evaluate(model,[X(ii), Y(jj)]);    
	   end
    end
	[min_val,min_idxs]=min(samples(:,3));
        minEntry = samples(min_idxs(1),:);
    if(debug)
        H1=figure;
        hold on
        surf(X,Y,meanVal)
        title('Expected value')
        xlabel(paramNames(1)) 
        ylabel(paramNames(2))
        scatter3(samples(:,1),samples(:,2),samples(:,3),50,[0 0 0],'filled')
        
        scatter3(minEntry(:,1),minEntry(:,2),minEntry(:,3),100,[1 0 0],'filled')
        savefig(H1,'Results/ExpectedValue.fig');
        hold off
        H2=figure;
        surf(X,Y,sqrt(varianceVal))
        title('Standard deviation')
        xlabel(paramNames(1)) 
        ylabel(paramNames(2))
        savefig(H2,'Results/StandardDeviation.fig');
    end
	bestSynthECG = bestSynthECGs(min_idxs(1));
    if(debug)
        plotMeanECG(bestSynthECG.mean,bestSynthECG.stdev,bestSynthECG.meanPhase,'Best synthetic');
        %[~,~,ECGmean_train,ECGsd_train,ECG_distr_train,meanphase_train,]=computeECGsdistance(filteredECG_validation,fs,synth_ECG,fs,false,true);
        %plotMeanECG(ECGmean_train,ECGsd_train,meanphase_train,'Original (training)');
        save('Results/workspace.mat');
        %%saving the results file
        save('Results/_minSample.txt','minEntry','-ascii');
    end
    SUMO2Cosmos(ParECG,minEntry);
    
    %%stopping Matlab execution
    exit
    
    
    
    
    
    
    


