function   SUMO2Cosmos( ParECG , ParSUMO )
%SUMO2Cosmos prints the results of ExtractParam in a Cosmos-friendly
%verion, so that it is possible to use it for the custom parameters model
%and the sthocasthic parameters model. I.E. this function generate two file
%1-distr_out.cpp: a file for the sthochastic model using the observed
%distributions
%2-ModelParam_out.csv: a comma separate value file of the model parameters
%observed, ready to be used by the custom parameters model

init_idx=11;
end_idx=15;
ParSUMO(1)=1000*ParSUMO(1);
ParECG=ParECG(2:end,:); %cleaning up the fisrt detection

Param=ParECG(:,init_idx:end_idx); %keeping only the intersting columns for ditr.cpp


PrintDistr(Param);

%%%Computing the Mean value of the ParECG
mean_param=mean(Param);
PrintModel(mean_param,ParSUMO);
PrintParECG( ParECG, ParSUMO);




end

function PrintDistr(Param)


fid=fopen('../ParamEstim/distr_out.cpp','w+');
fprintf(fid,'#define PI 3.141592l\n\n');

[M,N]=size(Param);



for ii=1:N
    
    string=['double DiscreteTab',int2str(ii),'[',int2str(M),'] = {' ,num2str(Param(1,ii))];
    for jj=2:M
        string=[string, ', ',num2str(Param(jj,ii)),];
    end
    string=[string,' };'];
    fprintf(fid, '%s\n\n',string);
    clear string;
end

fprintf(fid,'\n\ndouble drand_left(void);\n');
fprintf(fid,'double random_normal(void);\n');
fprintf(fid,'double scaled_normal(double const,double const);\n');
fprintf(fid,'double exponential(const double lambda);\n\n');

fprintf(fid,'double magicUDDD(std::vector<double> const& param,unsigned int i)\n{\n');
fprintf(fid,'    srand(i);\n');
fprintf(fid,'    switch((int)param[0])\n    {\n');

for ii=1:N
   string=['        case ', int2str(ii),': return(DiscreteTab', int2str(ii) ,'[i % ' int2str(M) ']);'];
   fprintf(fid,'%s\n',string);
end


fprintf(fid,'        default: THROW_ERROR;\n    }\n}\n\n\n');
fprintf(fid,'double drand_left()   /* uniform distribution, (0..1] */ \n{\n');
fprintf(fid,'    return((rand()+1.0)/(RAND_MAX+1.0));\n}\n\n');
fprintf(fid,'double random_normal()  /* normal distribution, centered on 0, std dev 1 */\n{\n');
fprintf(fid,'    return(sqrt(-2*log(drand_left())) * cos(2*PI*drand_left()));\n}\n\n');
fprintf(fid,'double scaled_normal(double const mean,double const std_dev)\n{\n');
fprintf(fid,'	return(mean + std_dev*random_normal());\n}\n');




fclose(fid);


end

function PrintModel(mean_param,ParSUMO)

mean_index=[1,2,3,4,5]; % the third indexes of the transition, doesn't correspond to any parameter on the model
mean2change=[24,20,33,22,31]; 
sumo_index=[1,1,2];
sumo2change=[3,8,13];


%creating header of the file
header=cell(0);
header{1,1}='Parameter';
header{1,2}='Value';
header{1,3}='Comment';


%%Building the deafult table
par_list{1,1}='Atr_refrD';
par_list{2,1}='AV_alpha';
par_list{3,1}='AV_anteDMin';
par_list{4,1}='AV_beta';
par_list{5,1}='AV_delta';
par_list{6,1}='AV_k4';
par_list{7,1}='AV_refrDMin';
par_list{8,1}='AV_retroDMin';
par_list{9,1}='AV_tauC';
par_list{10,1}='AV_theta';
par_list{11,1}='AV_tr';
par_list{12,1}='AV_Vr';
par_list{13,1}='AV_Vt';
par_list{14,1}='PM_TAVI';
par_list{15,1}='PM_TLRI';
par_list{16,1}='PM_TPVAB';
par_list{17,1}='PM_TPVARP';
par_list{18,1}='PM_TURI';
par_list{19,1}='PM_TVRP';
par_list{20,1}='RA_anteD';
par_list{21,1}='RA_retroD';
par_list{22,1}='RV_anteD';
par_list{23,1}='RV_retroD';
par_list{24,1}='SA_d';
par_list{25,1}='SA_dV';
par_list{26,1}='SA_ectopD';
par_list{27,1}='SA_ectopdV';
par_list{28,1}='SA_noiseD';
par_list{29,1}='VRG_ectopD';
par_list{30,1}='VRG_noiseD';
par_list{31,1}='Vtr_refrD';
par_list{32,1}='flag_delay';
par_list{33,1}='auxAVJDelay';

def_list{1,1}=num2str(50);
def_list{2,1}=num2str(150);
def_list{3,1}=num2str(50);
def_list{4,1}=num2str(250);
def_list{5,1}=num2str(10);
def_list{6,1}=num2str(0.03);
def_list{7,1}=num2str(50);
def_list{8,1}=num2str(50);
def_list{9,1}=num2str(100);
def_list{10,1}=num2str(10);
def_list{11,1}=num2str(500);
def_list{12,1}=num2str(-90);
def_list{13,1}=num2str(-40);
def_list{14,1}=num2str(160);
def_list{15,1}=num2str(1000);
def_list{16,1}=num2str(50);
def_list{17,1}=num2str(250);
def_list{18,1}=num2str(500);
def_list{19,1}=num2str(320);
def_list{20,1}=num2str(30);
def_list{21,1}=num2str(30);
def_list{22,1}=num2str(50);
def_list{23,1}=num2str(50);
def_list{24,1}=num2str(1000);
def_list{25,1}=num2str(50);
def_list{26,1}=num2str(10400);
def_list{27,1}=num2str(50);
def_list{28,1}=num2str(1000000);
def_list{29,1}=num2str(30450);
def_list{30,1}=num2str(1000000);
def_list{31,1}=num2str(200);
def_list{32,1}=num2str(1);
def_list{33,1}=num2str(60);




comm_list{1,1}='Atrial refractory period';
comm_list{2,1}='maximum AV node delay time';
comm_list{3,1}='minimum AV node antegrade conduction time';
comm_list{4,1}='maximum AV node refractory period';
comm_list{5,1}='electrotonic modulation constant for concealed impulse strength';
comm_list{6,1}='AV node spontaneous depolarisation slope';
comm_list{7,1}='minimum AV node refractory period';
comm_list{8,1}='minimum AV node retrograde conduction time';
comm_list{9,1}='AV node conduction time constant';
comm_list{10,1}='electrotonic modulation constant for concealed impulse timing';
comm_list{11,1}='AV node refractory time constant';
comm_list{12,1}='AV node resting potential';
comm_list{13,1}='AV node depolarisation threshold potential';
comm_list{14,1}='Set the maximum time allowed between an atrial and a ventricular events';
comm_list{15,1}='Set the upper time limit between two atrial events to occur';
comm_list{16,1}='Set the postventricular atrial blanking period';
comm_list{17,1}='Set the time interval after a ventricular event in which an atrial event nor inhibit an atrial pace nor activate a ventricular pace';
comm_list{18,1}='Set the upper time limit between two ventricular events to happen';
comm_list{19,1}='Set the time delay during which ventricular events are ignored by the pacemaker.';
comm_list{20,1}='Conduction delay from Atrium to RAConductor';
comm_list{21,1}='Conduction delay from RAConductor to Atrium';
comm_list{22,1}='Conduction delay from RVConductor to Ventricle';
comm_list{23,1}='Conduction delay from Ventricle to RVConductor';
comm_list{24,1}='SA node rate';
comm_list{25,1}='Voltage increment in AV node action potential due to atrial beat';
comm_list{26,1}='Rate of atrial ectopic beats';
comm_list{27,1}='Voltage increment in AV node potential due to atrial ectopic beat';
comm_list{28,1}='Rate of atrial sensor noise';
comm_list{29,1}='Rate of ventricular ectopic beats';
comm_list{30,1}='Rate of ventricular sensor noise';
comm_list{31,1}='Ventricular refractory period';
comm_list{32,1}='Set to 1 if you want to provide a AVJ Delay value set to 0 if you want the model to compute it in the usual way';
comm_list{33,1}='AVJ Delay this value is considered only if the above flag is activated';

%%Changing the parameter estimated

for ii=1:length(mean_index)

    def_list{mean2change(ii),1}=num2str(mean_param(mean_index(ii)));
 
end
for ii=1:length(sumo_index)
    
   def_list{sumo2change(ii),1}=num2str(ParSUMO(sumo_index(ii)));
    
end



list=[par_list,def_list,comm_list];


print2csv(list,header,'../ParamEstim/ModelParam_out.csv');


end


